aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/notification/type/base.php
diff options
context:
space:
mode:
authorPayBas <contact@paybas.com>2014-06-13 09:42:57 +0200
committerPayBas <contact@paybas.com>2014-06-15 10:02:11 +0200
commit8e06d76aaa5179096923971893c26a7f8bfe2fbe (patch)
treed4001f2ec2ec518aa69bf1cfd813b927f1146753 /phpBB/phpbb/notification/type/base.php
parenta9e6caa7756102e61ee50739ee562b0cf09965fd (diff)
downloadforums-8e06d76aaa5179096923971893c26a7f8bfe2fbe.tar
forums-8e06d76aaa5179096923971893c26a7f8bfe2fbe.tar.gz
forums-8e06d76aaa5179096923971893c26a7f8bfe2fbe.tar.bz2
forums-8e06d76aaa5179096923971893c26a7f8bfe2fbe.tar.xz
forums-8e06d76aaa5179096923971893c26a7f8bfe2fbe.zip
[ticket/12608] Changed get_styling() to get_style_class()
PHPBB3-12608
Diffstat (limited to 'phpBB/phpbb/notification/type/base.php')
-rw-r--r--phpBB/phpbb/notification/type/base.php15
1 files changed, 3 insertions, 12 deletions
diff --git a/phpBB/phpbb/notification/type/base.php b/phpBB/phpbb/notification/type/base.php
index db0446f510..910f51b3a6 100644
--- a/phpBB/phpbb/notification/type/base.php
+++ b/phpBB/phpbb/notification/type/base.php
@@ -308,24 +308,15 @@ abstract class base implements \phpbb\notification\type\type_interface
return array(
'NOTIFICATION_ID' => $this->notification_id,
-
- 'STYLING' => $this->get_styling(),
-
+ 'STYLING' => $this->get_style_class(),
'AVATAR' => $this->get_avatar(),
-
'FORMATTED_TITLE' => $this->get_title(),
-
'REFERENCE' => $this->get_reference(),
-
'FORUM' => $this->get_forum(),
-
'REASON' => $this->get_reason(),
-
'URL' => $this->get_url(),
'TIME' => $this->user->format_date($this->notification_time),
-
'UNREAD' => !$this->notification_read,
-
'U_MARK_READ' => (!$this->notification_read) ? $u_mark_read : '',
);
}
@@ -345,11 +336,11 @@ abstract class base implements \phpbb\notification\type\type_interface
}
/**
* Get the styling of the notification (fall back)
*
* @return string
*/
- public function get_styling()
+ public function get_style_class()
{
return '';
}
@@ -345,11 +336,11 @@ abstract class base implements \phpbb\notification\type\type_interface
}
/**
- * Get the styling of the notification (fall back)
+ * Get the CSS style class of the notification (fall back)
*
* @return string